Subject: [PATCH] update stand alone program support to remove #ifdef maze

Signed-off-by: Jeffrey Mann <mannj@embeddedplanet.com>
---
 common/exports.c   |   40 ++++++++++++++++++++++++----------------
 include/_exports.h |    4 ++--
 include/exports.h  |    3 +--
 3 files changed, 27 insertions(+), 20 deletions(-)

diff --git a/common/exports.c b/common/exports.c
index 0cb4396..5af2a06
--- a/common/exports.c
+++ b/common/exports.c
@@ -7,6 +7,26 @@ static void dummy(void)
 {
 }
 
+#define EXPORT_FUNC(x) asm(".weak\t" #x "\n\t.set\t" #x ",dummy");
+#include <_exports.h>
+#undef EXPORT_FUNC
+
+/*
+ * xf_func_inc(int) is used to determine whether a function has been compiled 
+ * with u-boot and available for use by a stand alone program . This allows a 
+ * stand alone program to ensure that a function exists before running code with
+ * the an exported function in it. 
+ *
+ * function_id is defined by the enum type of _exports.h. For example, 
+ *   xf_func_inc(XF_foobar)
+ *   returns 0 if the function foobar() is available
+ *   returns 1 if the function foobar() has not been compiled with u-boot 
+ */
+int xf_func_inc(int function_id)
+{		
+	return (gd->jt[function_id] == (void *) dummy);
+}
+
 unsigned long get_version(void)
 {
 	return XF_VERSION;
@@ -20,20 +40,8 @@ void jumptable_init (void)
 	for (i = 0; i < XF_MAX; i++)
 		gd->jt[i] = (void *) dummy;
 
-	gd->jt[XF_get_version] = (void *) get_version;
-	gd->jt[XF_malloc] = (void *) malloc;
-	gd->jt[XF_free] = (void *) free;
-	gd->jt[XF_getenv] = (void *) getenv;
-	gd->jt[XF_setenv] = (void *) setenv;
-	gd->jt[XF_get_timer] = (void *) get_timer;
-	gd->jt[XF_simple_strtoul] = (void *) simple_strtoul;
-	gd->jt[XF_udelay] = (void *) udelay;
-#if defined(CONFIG_I386) || defined(CONFIG_PPC)
-	gd->jt[XF_install_hdlr] = (void *) irq_install_handler;
-	gd->jt[XF_free_hdlr] = (void *) irq_free_handler;
-#endif	/* I386 || PPC */
-#if (CONFIG_COMMANDS & CFG_CMD_I2C)
-	gd->jt[XF_i2c_write] = (void *) i2c_write;
-	gd->jt[XF_i2c_read] = (void *) i2c_read;
-#endif	/* CFG_CMD_I2C */
+#define EXPORT_FUNC(x) gd->jt[XF_ ## x ] = (void *) x ;
+#include <_exports.h>
+#undef EXPORT_FUNC
+
 }
diff --git a/include/_exports.h b/include/_exports.h
index 2b8ec3d..96623db
--- a/include/_exports.h
+++ b/include/_exports.h
@@ -15,7 +15,7 @@ EXPORT_FUNC(do_reset)
 EXPORT_FUNC(getenv)
 EXPORT_FUNC(setenv)
 EXPORT_FUNC(simple_strtoul)
-#if (CONFIG_COMMANDS & CFG_CMD_I2C)
+EXPORT_FUNC(xf_func_inc)
 EXPORT_FUNC(i2c_write)
 EXPORT_FUNC(i2c_read)
-#endif	/* CFG_CMD_I2C */
+
diff --git a/include/exports.h b/include/exports.h
index 8f7f617..22f9605
--- a/include/exports.h
+++ b/include/exports.h
@@ -23,10 +23,9 @@ void do_reset (void);
 unsigned long simple_strtoul(const char *cp,char **endp,unsigned int base);
 char *getenv (char *name);
 void setenv (char *varname, char *varvalue);
-#if (CONFIG_COMMANDS & CFG_CMD_I2C)
 int i2c_write (uchar, uint, int , uchar* , int);
 int i2c_read (uchar, uint, int , uchar* , int);
-#endif	/* CFG_CMD_I2C */
+int xf_func_inc(int);
 
 void app_startup(char **);
 
-- 
1.4.1

